@@ -12,6 +12,8 @@ usage() {
 	  -Dkey=val      Option to pass on to meson
 	  --subdir       Build subdirectory instead of whole project
 	  --prepare      Script to run before build
+	  --libdir       Setup the project with a different libdir
+	  --destdir      Install the project to an additional destdir
 
 	  -h, --help     Display this help
 
@@ -23,6 +25,8 @@ TEMP=$(getopt \
   --options='D:h' \
   --longoptions='subdir:' \
   --longoptions='prepare:' \
+  --longoptions='libdir:' \
+  --longoptions='destdir:' \
   --longoptions='help' \
   -- "$@")
 
@@ -32,6 +36,7 @@ unset TEMP
 MESON_OPTIONS=()
 SUBDIR=.
 PREPARE=:
+DESTDIR=""
 
 while true; do
   case "$1" in
@@ -50,6 +55,16 @@ while true; do
       shift 2
     ;;
 
+    --libdir)
+      MESON_OPTIONS+=( --libdir=$2 )
+      shift 2
+    ;;
+
+    --destdir)
+      DESTDIR=$2
+      shift 2
+    ;;
+
     -h|--help)
       usage
       exit 0
@@ -78,5 +93,11 @@ git clone --depth 1 "$REPO_URL" -b "$COMMIT" "$CHECKOUT_DIR"
 pushd "$CHECKOUT_DIR/$SUBDIR"
 sh -c "$PREPARE"
 meson setup --prefix=/usr _build "${MESON_OPTIONS[@]}"
+
+# Install it to an additional directory e.g., system extension directory
+if [ -n "${DESTDIR}" ]; then
+    sudo meson install -C _build --destdir=$DESTDIR
+fi
+
 sudo meson install -C _build
 popd
