@@ -1304,7 +1304,7 @@ export const Keyboard = GObject.registerClass({
         this._keyboardController.connectObject(
             'group-changed', this._onGroupChanged.bind(this),
             'panel-state', this._onKeyboardStateChanged.bind(this),
-            'purpose-changed', this._onPurposeChanged.bind(this),
+            'purpose-changed', () => this._updateKeys(),
             'content-hints-changed', this._onContentHintsChanged.bind(this),
             this);
         global.stage.connectObject('notify::key-focus',
@@ -1313,11 +1313,6 @@ export const Keyboard = GObject.registerClass({
         this._relayout();
     }
 
-    _onPurposeChanged(controller, purpose) {
-        this._purpose = purpose;
-        this._updateKeys();
-    }
-
     _onContentHintsChanged(controller, contentHint) {
         this._contentHint = contentHint;
         this._updateLevelFromHints(false);
@@ -1658,7 +1653,8 @@ export const Keyboard = GObject.registerClass({
 
     _updateKeys() {
         const group = this._keyboardController.getCurrentGroup();
-        this._updateLayout(group, this._purpose);
+        const {purpose} = this._keyboardController;
+        this._updateLayout(group, purpose);
         this._setActiveLevel('default');
     }
 
@@ -1992,6 +1988,7 @@ class KeyboardController extends Signals.EventEmitter {
             'current-source-changed', this._onSourceChanged.bind(this),
             'sources-changed', this._onSourcesModified.bind(this), this);
         this._currentSource = this._inputSourceManager.currentSource;
+        this._purpose = Main.inputMethod.contentPurpose;
 
         Main.inputMethod.connectObject(
             'notify::content-purpose', this._onPurposeHintsChanged.bind(this),
@@ -1999,6 +1996,10 @@ class KeyboardController extends Signals.EventEmitter {
             'input-panel-state', (o, state) => this.emit('panel-state', state), this);
     }
 
+    get purpose() {
+        return this._purpose;
+    }
+
     destroy() {
         this._inputSourceManager.disconnectObject(this);
         Main.inputMethod.disconnectObject(this);
