@@ -1,5 +1,4 @@
-#ifndef __SHELL_WINDOW_PREVIEW_LAYOUT_H__
-#define __SHELL_WINDOW_PREVIEW_LAYOUT_H__
+#pragma once
 
 G_BEGIN_DECLS
 
@@ -29,5 +28,3 @@ void  shell_window_preview_layout_remove_window (ShellWindowPreviewLayout  *self
 GList * shell_window_preview_layout_get_windows (ShellWindowPreviewLayout  *self);
 
 G_END_DECLS
-
-#endif /* __SHELL_WINDOW_PREVIEW_LAYOUT_H__ */
