@@ -1,5 +1,4 @@
-#ifndef __SHELL_WINDOW_PREVIEW_H__
-#define __SHELL_WINDOW_PREVIEW_H__
+#pragma once
 
 #include <st/st.h>
 
@@ -10,5 +9,3 @@ G_DECLARE_FINAL_TYPE (ShellWindowPreview, shell_window_preview,
                       SHELL, WINDOW_PREVIEW, StWidget)
 
 G_END_DECLS
-
-#endif /* __SHELL_WINDOW_PREVIEW_H__ */
