@@ -1,6 +1,5 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
-#ifndef __SHELL_WM_H__
-#define __SHELL_WM_H__
+#pragma once
 
 #include <glib-object.h>
 #include <meta/meta-plugin.h>
@@ -28,5 +27,3 @@ void     shell_wm_complete_display_change    (ShellWM         *wm,
                                               gboolean         ok);
 
 G_END_DECLS
-
-#endif /* __SHELL_WM_H__ */
