@@ -18,8 +18,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __ST_THEME_NODE_TRANSITION_H__
-#define __ST_THEME_NODE_TRANSITION_H__
+#pragma once
 
 #include <clutter/clutter.h>
 
@@ -55,5 +54,3 @@ void  st_theme_node_transition_get_paint_box (StThemeNodeTransition *transition,
 StThemeNodePaintState * st_theme_node_transition_get_new_paint_state (StThemeNodeTransition *transition);
 
 G_END_DECLS
-
-#endif
